@@ -3,6 +3,7 @@ import traceback
 import pandas as pd
 import pytest
 from pytest_html import extras
+from .utils.general.Wrapit import Wrapit
 from .drivers.browsers import browser_os_name_conf
 from .conf.rwd.Website import base_url_conf
 from .utils import html_report_conf
@@ -221,8 +222,8 @@ def pytest_runtest_makereport(item, call):
     report = outcome.get_result()
     extra = getattr(report, "extra", [])
     if report.when == "call":
-        test_func = test_obj
-        screenshot_name = '%003d' % test_func.screenshot_counter + '' + test_func.name_
+        test_func = item.parent.obj
+        screenshot_name = '%003d' % Wrapit.screenshot_counter + '' + test_func.__name__
         # extra.append(pytest_html.extras.url(test_obj.screenshot_dir, name="Screenshot Folder"))
         filename = f'{screenshot_name}.png'
         extra.append(pytest_html.extras.image(filename))
